| regMat | R Documentation |
Determines a matrix of potential regulatory TFs.
regMat(geneToPeak, matches)
geneToPeak |
A 2-column matrix with the first row corresponding to the |
matches |
An output from |
A logical matrix with columns corresponding to the motifs in matches and rows corresponding to the genes in geneToPeak.
getOverlaps, matchMotifs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.